@@ -35,9 +35,15 @@
 #include <regex.h>
 #include <apt-pkg/depcache.h>
 #include <apt-pkg/acquire.h>
+#include <apt-pkg/progress.h>
+
+#ifdef WITH_EPT
+#include <ept/axi/axi.h>
+#endif
 
 #include "rpackagecache.h"
 #include "rpackage.h"
+#include "rpackagestatus.h"
 #include "rpackageview.h"
 #include "ruserdialog.h"
 #include "config.h"
@@ -101,6 +107,11 @@ class RPackageLister {
    pkgRecords *_records;
    OpProgress *_progMeter;
 
+#ifdef WITH_EPT
+   Xapian::Database *_xapianDatabase;
+#endif
+
+
    // Other members.
    vector<RPackage *> _packages;
    vector<int> _packagesIndex;
@@ -122,13 +133,18 @@ class RPackageLister {
 
    RPackageViewFilter *_filterView; // the package view that does the filtering
    RPackageViewSearch *_searchView; // the package view that does the (simple) search
-   
+
+   // helper for the limitBySearch() code
+   bool xapianSearch(string searchString);
+
    public:
 
    unsigned int _viewMode;
 
    typedef enum {
-      LIST_SORT_NAME,
+      LIST_SORT_DEFAULT,
+      LIST_SORT_NAME_ASC,
+      LIST_SORT_NAME_DES,
       LIST_SORT_SIZE_ASC,
       LIST_SORT_SIZE_DES,
       LIST_SORT_SUPPORTED_ASC,
@@ -188,6 +204,9 @@ class RPackageLister {
    list<pkgState> redoStack;
 
    public:
+   // limit what the current view displays
+   bool limitBySearch(string searchString);
+
    // clean files older than "Synaptic::delHistory"
    void cleanCommitLog();
 
@@ -204,6 +223,9 @@ class RPackageLister {
 
    // this needs a different name, something like refresh
    void reapplyFilter();
+   
+   // refresh view 
+   void refreshView();
 
    // is is exposed for the stuff like filter manager window
    RPackageViewFilter *filterView() { return _filterView; };
@@ -264,7 +286,8 @@ class RPackageLister {
                         vector<RPackage *> &toRemove,
                         vector<RPackage *> &toDowngrade,
 			vector<RPackage *> &notAuthenticated,
-                        vector<RPackage *> &exclude, bool sorted = true);
+                        const vector<RPackage *> &exclude, 
+                        bool sorted = true);
 
    // open (lock if run as root)
    bool openCache();
@@ -317,6 +340,11 @@ class RPackageLister {
    bool writeSelections(ostream &out, bool fullState);
 
    RPackageCache* getCache() { return _cache; };
+#ifdef WITH_EPT
+   Xapian::Database* xapiandatabase() { return _xapianDatabase; }
+   bool xapianIndexNeedsUpdate();
+   bool openXapianIndex();
+#endif
 
    RPackageLister();
    ~RPackageLister();
